@@ -1,6 +1,6 @@
 package MARC::Moose::Lint::Checker::RulesFile;
 # ABSTRACT: A class to 'lint' biblio record based on a rules file
-$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.24';
+$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.25';
 use Moose;
 use Modern::Perl;
 
@@ -86,11 +86,10 @@ sub _set_file {
     $self->rules( \%rules );
 
     my $code;
-    if ( /^====/ ) {
+    if ( $_ && /^====/ ) {
         while (1) {
             if (/^==== *([A-Z]*) *(.*)$/) {
                 ($code) = $1;
-                say $2;
                 for my $value ( split / +/, $2 ) {
                     say $_;
                     my $values = [ $code ];
@@ -118,8 +117,6 @@ sub _set_file {
             s/ *$//;
         }
     }
-    use YAML;
-    say Dump( $self->tablecheck );
 }
 
 
@@ -162,6 +159,7 @@ sub check {
         ($tag, $mandatory, $repeatable) = @$rule;
         my $fields = $fields_by_tag->{$tag};
         unless ($fields) {
+            @fields = ();
             $append->("missing mandatory field") if $mandatory;
             next;
         }
@@ -296,7 +294,7 @@ MARC::Moose::Lint::Checker::RulesFile - A class to 'lint' biblio record based on
 
 =head1 VERSION
 
-version 1.0.24
+version 1.0.25
 
 =head1 DESCRIPTION
 
